==> belenios_1.19+dfsg.orig.tar.xz: belenios-1.19/src/web/server/common/accounts.mli <==
(**************************************************************************)
(*                                BELENIOS                                *)
(*                                                                        *)
(*  Copyright © 2012-2021 Inria                                           *)
(*                                                                        *)
(*  This program is free software: you can redistribute it and/or modify  *)
(*  it under the terms of the GNU Affero General Public License as        *)
(*  published by the Free Software Foundation, either version 3 of the    *)
(*  License, or (at your option) any later version, with the additional   *)
(*  exemption that compiling, linking, and/or using OpenSSL is allowed.   *)
(*                                                                        *)
(*  This program is distributed in the hope that it will be useful, but   *)
(*  WITHOUT ANY WARRANTY; without even the implied warranty of            *)
(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *)
(*  Affero General Public License for more details.                       *)
(*                                                                        *)
(*  You should have received a copy of the GNU Affero General Public      *)
(*  License along with this program.  If not, see                         *)
(*  <http://www.gnu.org/licenses/>.                                       *)
(**************************************************************************)

open Web_serializable_t

val create_account : email:string -> user -> account Lwt.t
val get_account_by_id : int -> account option Lwt.t
val get_account : user -> account option Lwt.t

val update_account : account -> unit Lwt.t
val add_update_hook : (account -> unit Lwt.t) -> unit

type capability =
  | Sudo

val has_capability : capability -> account -> bool

val check : user * account * string -> user user_or_id -> bool
val check_account : account -> user user_or_id -> bool

==> belenios_2.0+dfsg.orig.tar.xz: belenios-2.0/src/web/server/common/accounts.mli <==
(**************************************************************************)
(*                                BELENIOS                                *)
(*                                                                        *)
(*  Copyright © 2012-2021 Inria                                           *)
(*                                                                        *)
(*  This program is free software: you can redistribute it and/or modify  *)
(*  it under the terms of the GNU Affero General Public License as        *)
(*  published by the Free Software Foundation, either version 3 of the    *)
(*  License, or (at your option) any later version, with the additional   *)
(*  exemption that compiling, linking, and/or using OpenSSL is allowed.   *)
(*                                                                        *)
(*  This program is distributed in the hope that it will be useful, but   *)
(*  WITHOUT ANY WARRANTY; without even the implied warranty of            *)
(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *)
(*  Affero General Public License for more details.                       *)
(*                                                                        *)
(*  You should have received a copy of the GNU Affero General Public      *)
(*  License along with this program.  If not, see                         *)
(*  <http://www.gnu.org/licenses/>.                                       *)
(**************************************************************************)

open Web_serializable_t

val create_account : email:string -> user -> account Lwt.t
val get_account_by_id : int -> account option Lwt.t
val get_account : user -> account option Lwt.t

val update_account : account -> unit Lwt.t
val add_update_hook : (account -> unit Lwt.t) -> unit

type capability =
  | Sudo

val has_capability : capability -> account -> bool

val check : account -> int list -> bool
